@@ -36,7 +36,8 @@ getCounts <- function(xyt,subset=rep(TRUE,xyt$n),M,N,ext){
 	ywd	<- diff(bbox[2,])/N
 	sg <- SpatialGrid(GridTopology(c(bbox[1,1]+xwd/2,bbox[2,1]+ywd/2),c(xwd,ywd),c(M,N)))
 	sp <- SpatialPoints(matrix(cbind(xyt$x,xyt$y)[subset,],sum(subset),2))
-	ol <- overlay(sg,sp)
+	#EJP: ol <- overlay(sg,sp)
+	ol <- over(sp, sg)
 	tol <- table(ol)
 	idx <- as.numeric(rownames(tol))	
 	smat <- matrix(0,M,N)
@@ -68,7 +69,8 @@ getCellCounts <- function(x,y,xgrid,ygrid){
     ywd <- diff(ygrid[1:2])
 	sg <- SpatialGrid(GridTopology(c(xgrid[1],ygrid[1]),c(xwd,ywd),c(M,N)))
 	sp <- SpatialPoints(cbind(x,y))
-	ol <- overlay(sg,sp)
+	#EJP: ol <- overlay(sg,sp)
+	ol <- over(sp,sg)
 	tol <- table(ol)
 	idx <- as.numeric(rownames(tol))	
 	smat <- matrix(0,M,N)
